package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.WechatTransfer;

/**
 * wechat_transferMapper接口
 * 
 * @author ruoyi
 * @date 2025-05-15
 */
public interface WechatTransferMapper 
{
    /**
     * 查询wechat_transfer
     * 
     * @param id wechat_transfer主键
     * @return wechat_transfer
     */
    public WechatTransfer selectWechatTransferById(Long id);

    /**
     * 查询wechat_transfer列表
     * 
     * @param wechatTransfer wechat_transfer
     * @return wechat_transfer集合
     */
    public List<WechatTransfer> selectWechatTransferList(WechatTransfer wechatTransfer);

    /**
     * 新增wechat_transfer
     * 
     * @param wechatTransfer wechat_transfer
     * @return 结果
     */
    public int insertWechatTransfer(WechatTransfer wechatTransfer);

    /**
     * 修改wechat_transfer
     * 
     * @param wechatTransfer wechat_transfer
     * @return 结果
     */
    public int updateWechatTransfer(WechatTransfer wechatTransfer);

    /**
     * 删除wechat_transfer
     * 
     * @param id wechat_transfer主键
     * @return 结果
     */
    public int deleteWechatTransferById(Long id);

    /**
     * 批量删除wechat_transfer
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWechatTransferByIds(Long[] ids);
}
